Struct raw_window_handle::DisplayHandle
source · #[repr(transparent)]pub struct DisplayHandle<'a> { /* private fields */ }Available on crate feature
std or non-Android only.Expand description
The handle to the display controller of the windowing system.
This is the primary return type of the HasDisplayHandle trait. It is guaranteed to contain
a valid platform-specific display handle for its lifetime.
Get the underlying raw display handle with the HasRawDisplayHandle trait.
Implementations
sourceimpl<'a> DisplayHandle<'a>
impl<'a> DisplayHandle<'a>
sourcepub unsafe fn borrow_raw(raw: RawDisplayHandle) -> Self
pub unsafe fn borrow_raw(raw: RawDisplayHandle) -> Self
Create a DisplayHandle from a RawDisplayHandle.
Safety
The RawDisplayHandle must be valid for the lifetime.