WebOffscreenCanvasWindowHandle

Struct WebOffscreenCanvasWindowHandle 

#[non_exhaustive]
pub struct WebOffscreenCanvasWindowHandle { pub obj: NonNull<c_void>, }
Raw window handle for a Web offscreen canvas registered via wasm-bindgen.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
obj: NonNull<c_void>

A pointer to the JsValue of an OffscreenCanvas.

Note: This uses c_void to avoid depending on wasm-bindgen directly.

Implementations

Source

impl WebOffscreenCanvasWindowHandle

pub fn new(obj: NonNull<c_void>) -> Self

Create a new handle from a pointer to an OffscreenCanvas.

Example
let canvas: &OffscreenCanvas;
let value: &JsValue = &canvas; // Deref to `JsValue`
let obj: NonNull<c_void> = NonNull::from(value).cast();
let mut handle = WebOffscreenCanvasWindowHandle::new(obj);